@@ -1,4 +1,4 @@
-/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1995 
+/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1995, 1996, 1997 
  * Jamie Zawinski <jwz@netscape.com>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -22,16 +22,10 @@
 #define MAX(a,b) ((a)>(b)?(a):(b))
 #define MIN(a,b) ((a)<(b)?(a):(b))
 
-#ifdef __STDC__
-# define P(x)x
-#else /* !__STDC__ */
-# define P(x)()
-#endif
-
-static void KbdResize ();
-static void KbdRealize ();
-static void KbdInitialize ();
-static void ChangeManaged ();
+static void KbdResize P((Widget));
+static void KbdRealize P((Widget, Mask *, XSetWindowAttributes *));
+static void KbdInitialize P((Widget, Widget, ArgList, Cardinal*));
+static void ChangeManaged P((Widget));
 static XtGeometryResult GeometryManager P((Widget w,
 					   XtWidgetGeometry *request,
 					   XtWidgetGeometry *reply));
@@ -39,11 +33,9 @@ static XtGeometryResult PreferredSize P((Widget w,
 					 XtWidgetGeometry *request,
 					 XtWidgetGeometry *preferred));
 static void make_key_widgets P((KeyboardWidget widget,
-				struct keyboard_instance *kbd));
+				const struct keyboard_instance *kbd));
 static void set_icon_pixmap P((KeyboardWidget keyboard,
-			       struct keyboard_instance *kbd));
-
-extern void init_modifier_mapping P((KeyboardWidget widget));
+			       const struct keyboard_instance *kbd));
 
 
 static XtResource keyboard_resources [] = {
@@ -58,17 +50,6 @@ static XtResource keyboard_resources [] = {
       "crosshair" }
 };
 
-extern void highlight_key_action ();
-extern void unhighlight_key_action ();
-extern void toggle_key_action ();
-extern void simulate_KeyPress_action ();
-extern void simulate_KeyRelease_action ();
-extern void track_key_action ();
-extern void untrack_key_action ();
-extern void describe_key_action ();
-extern void keyboard_track_motion_hook ();
-extern void key_menu_popup_action ();
-
 XtActionsRec keyboard_actions [] = {
   {"HighlightKey",	highlight_key_action},
   {"UnhighlightKey",	unhighlight_key_action},
@@ -158,15 +139,22 @@ KeyboardClassRec keyboardClassRec = {
 WidgetClass keyboardWidgetClass = (WidgetClass) &keyboardClassRec;
 
 static void 
-KbdInitialize (r, n)
+#ifdef __STDC__
+KbdInitialize (Widget r, Widget n, ArgList al, Cardinal *ac)
+#else /* ! __STDC__ */
+KbdInitialize (r, n, al, ac)
      Widget r, n;
+     ArgList al;
+     Cardinal *ac;
+#endif /* ! __STDC__ */
 {
   KeyboardWidget new = (KeyboardWidget) n;
-  struct keyboard_instance *kbd =
+  const struct keyboard_instance *kbd =
     choose_kbd (XtDisplay (new), new->keyboard.kbd_name);
 
   new->keyboard.short_name = kbd->short_name;
-  new->keyboard.long_name = kbd->long_name;
+  new->keyboard.vendor = kbd->vendor;
+  new->keyboard.kbd_style = kbd->kbd_style;
   new->keyboard.default_scale = kbd->keyboard_geometry->default_scale;
   new->keyboard.horiz_border = kbd->keyboard_geometry->horiz_border;
   new->keyboard.vert_border = kbd->keyboard_geometry->vert_border;
@@ -188,8 +176,12 @@ KbdInitialize (r, n)
 }
 
 static void
+#ifdef __STDC__
+do_layout (KeyboardWidget parent)
+#else /* ! __STDC__ */
 do_layout (parent)
      KeyboardWidget parent;
+#endif /* ! __STDC__ */
 {
   int i, j;
   int width = parent->core.width;
@@ -243,33 +235,54 @@ do_layout (parent)
 }
 
 
-static void KbdResize (w)
+static void
+#ifdef __STDC__
+KbdResize (Widget w)
+#else /* ! __STDC__ */
+KbdResize (w)
      Widget w;
+#endif /* ! __STDC__ */
 {
     do_layout ((KeyboardWidget) w);
 }
 
 
 static XtGeometryResult
+#ifdef __STDC__
+PreferredSize (Widget w,
+	       XtWidgetGeometry *request,
+	       XtWidgetGeometry *preferred)
+#else /* ! __STDC__ */
 PreferredSize (w, request, preferred)
      Widget w;
      XtWidgetGeometry *request, *preferred;
+#endif /* ! __STDC__ */
 {
   return XtGeometryYes;
 }
 
 static XtGeometryResult
+#ifdef __STDC__
+GeometryManager (Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
+#else /* ! __STDC__ */
 GeometryManager (w, request, reply)
      Widget w;
      XtWidgetGeometry *request, *reply;
+#endif /* ! __STDC__ */
 {
   return XtGeometryNo;
 }
 
 
-static void ChangeManaged (w)
-     KeyboardWidget w;
+static void
+#ifdef __STDC__
+ChangeManaged (Widget ww)
+#else /* ! __STDC__ */
+ChangeManaged (ww)
+     Widget ww;
+#endif /* ! __STDC__ */
 {
+  KeyboardWidget w = (KeyboardWidget) ww;
     if (w->core.width <= 0 || w->core.height <= 0)
       {
 	int default_scale = w->keyboard.default_scale;
@@ -283,10 +296,14 @@ static void ChangeManaged (w)
 
 
 static void
+#ifdef __STDC__
+KbdRealize (Widget widget, Mask *value_mask, XSetWindowAttributes *attributes)
+#else /* ! __STDC__ */
 KbdRealize (widget, value_mask, attributes)
     Widget widget;
     Mask *value_mask;
     XSetWindowAttributes *attributes;
+#endif /* ! __STDC__ */
 {
   XtAppContext app = XtWidgetToApplicationContext (widget);
   XtAppAddActionHook (app, keyboard_track_motion_hook, (XtPointer) widget);
@@ -301,9 +318,13 @@ KbdRealize (widget, value_mask, attributes)
 
 
 static void
+#ifdef __STDC__
+make_key_widgets (KeyboardWidget widget, const struct keyboard_instance *kbd)
+#else /* ! __STDC__ */
 make_key_widgets (widget, kbd)
      KeyboardWidget widget;
-     struct keyboard_instance *kbd;
+     const struct keyboard_instance *kbd;
+#endif /* ! __STDC__ */
 {
   Arg av [20];
   int ac;
@@ -313,11 +334,11 @@ make_key_widgets (widget, kbd)
   int default_scale = widget->keyboard.default_scale;
   int nrows = kbd->keyboard_geometry->nrows;
 
-  struct key_strings *strings = kbd->key_strings;
+  const struct key_strings *strings = kbd->key_strings;
   int nstrings = kbd->key_strings_count;
-  KeyCode *keycodes = kbd->keycodes;
+  const KeyCode *keycodes = kbd->keycodes;
   int ncodes = kbd->keycodes_count;
-  struct default_keycode_map *keysyms = kbd->default_keycode_map;
+  const struct default_keycode_map *keysyms = kbd->default_keycode_map;
   int nsyms = kbd->default_keycode_map_count;
 
   int index = 0;
@@ -368,8 +389,9 @@ make_key_widgets (widget, kbd)
       for (j = 0; j < row->nkeys; j++)
 	{
 	  KeyWidget kw = 0;
-	  struct key_geometry *key = &kbd->keyboard_geometry->rows[i].keys[j];
-	  struct key_strings *ss;
+	  const struct key_geometry *key =
+	    &kbd->keyboard_geometry->rows[i].keys[j];
+	  const struct key_strings *ss;
 	  KeyCode kk;
 	  int place_holder_p = (key->height == 0);
 
@@ -377,7 +399,7 @@ make_key_widgets (widget, kbd)
 	    {
 	      int ks_count;
 	      int a = 0;
-	      char *wname;
+	      const char *wname;
 
 	      if (index >= nstrings || index >= ncodes)
 		{
@@ -477,7 +499,7 @@ make_key_widgets (widget, kbd)
 
 static struct icon
 {
-  struct keyboard_geometry *geom;
+  const struct keyboard_geometry *geom;
   Pixmap pixmap, /* pixmap2, */ mask;
   int width;
   int height;
@@ -486,8 +508,12 @@ static int nicons;
 static int max_icon_width;
 
 static struct icon *
+#ifdef __STDC__
+find_icon (const struct keyboard_geometry *geom)
+#else /* ! __STDC__ */
 find_icon (geom)
-     struct keyboard_geometry *geom;
+     const struct keyboard_geometry *geom;
+#endif /* ! __STDC__ */
 {
   struct icon *i;
   for (i = all_icons; i->geom; i++)
@@ -500,9 +526,13 @@ static unsigned long gc_mask;
 static XGCValues gc_values;
 
 static void
+#ifdef __STDC__
+create_icon_pixmap (Display *dpy, const struct keyboard_geometry *geom)
+#else /* ! __STDC__ */
 create_icon_pixmap (dpy, geom)
      Display *dpy;
-     struct keyboard_geometry *geom;
+     const struct keyboard_geometry *geom;
+#endif /* ! __STDC__ */
 {
   int scale = 3;
   Pixmap pixmap, /* pixmap2, */ mask;
@@ -570,7 +600,7 @@ create_icon_pixmap (dpy, geom)
       kx = 0;
       for (j = 0; j < geom->rows[i].nkeys; j++)
 	{
-	  struct key_geometry *key = &geom->rows[i].keys[j];
+	  const struct key_geometry *key = &geom->rows[i].keys[j];
 	  int x, y, x2, y2, w, h;
 
 	  x = (kx * scale / key_size) + scale;
@@ -604,8 +634,12 @@ create_icon_pixmap (dpy, geom)
 }
 
 void
+#ifdef __STDC__
+create_icon_pixmaps (Display *dpy)
+#else /* ! __STDC__ */
 create_icon_pixmaps (dpy)
      Display *dpy;
+#endif /* ! __STDC__ */
 {
   int kbd_count = 0;
   while (all_kbds [kbd_count++].short_name)
@@ -618,9 +652,13 @@ create_icon_pixmaps (dpy)
 }
 
 static void
+#ifdef __STDC__
+set_icon_pixmap (KeyboardWidget keyboard, const struct keyboard_instance *kbd)
+#else /* ! __STDC__ */
 set_icon_pixmap (keyboard, kbd)
      KeyboardWidget keyboard;
-     struct keyboard_instance *kbd;
+     const struct keyboard_instance *kbd;
+#endif /* ! __STDC__ */
 {
   Arg av [5];
   int ac;
@@ -641,10 +679,15 @@ set_icon_pixmap (keyboard, kbd)
 }
 
 Pixmap
+#ifdef __STDC__
+get_keyboard_icon (Display *dpy, const struct keyboard_instance *kbd,
+		   int *wP, int *hP)
+#else /* ! __STDC__ */
 get_keyboard_icon (dpy, kbd, wP, hP)
      Display *dpy;
-     struct keyboard_instance *kbd;
+     const struct keyboard_instance *kbd;
      int *wP, *hP;
+#endif /* ! __STDC__ */
 {
   struct icon *i = find_icon (kbd->keyboard_geometry);
   if (!i) /* not in the cache */
