@@ -18,7 +18,7 @@ typedef struct _KeyClassRec *KeyWidgetClass;
 
 extern WidgetClass keyWidgetClass;
 
-#if __STDC__
+#ifdef __STDC__
 extern void KeyHighlight (KeyWidget);
 extern void KeyDehighlight (KeyWidget);
 #endif
