@@ -1,4 +1,5 @@
-/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
+/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1996
+ *  Jamie Zawinski <jwz@netscape.com>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -9,38 +10,16 @@
  * implied warranty.
  */
 
-#if __STDC__
-#include <stdlib.h>
-#endif
-
 #include <stdio.h>
 #include "KbdWidgetP.h"
 #include "KeyWidgetP.h"
 #include "xkeycaps.h"
 
-extern int string_equal ();
-
-void highlight_key_action ();
-void unhighlight_key_action ();
-void toggle_key_action ();
-void simulate_KeyPress_action ();
-void simulate_KeyRelease_action ();
-void track_key_action ();
-void untrack_key_action ();
-void describe_key_action ();
-
-static void highlight_key ();
-static void dehighlight_key ();
-static void mouse_highlight_key ();
-static void mouse_dehighlight_key ();
-
-static void simulate_key_event ();
-void key_to_event ();
-
-KeyWidget keycode_to_key ();
-KeyWidget window_to_key ();
-
-void init_modifier_mapping ();
+static void highlight_key P((KeyWidget widget));
+static void dehighlight_key P((KeyWidget widget));
+static void mouse_highlight_key P((KeyWidget widget));
+static void mouse_dehighlight_key P((KeyWidget widget));
+static void simulate_key_event P((KeyWidget widget, int down_p));
 
 
 
@@ -67,7 +46,11 @@ void init_modifier_mapping ();
  */
 
 
-KeyWidget
+static KeyWidget
+#ifdef __STDC__
+parse_key_action_args (char *name, XEvent *event, char **argv, int argc,
+		       KeyboardWidget widget, int *mouse_p_ret)
+#else /* ! __STDC__ */
 parse_key_action_args (name, event, argv, argc, widget, mouse_p_ret)
      char *name;
      XEvent *event;
@@ -75,6 +58,7 @@ parse_key_action_args (name, event, argv, argc, widget, mouse_p_ret)
      int argc;
      KeyboardWidget widget;
      int *mouse_p_ret;
+#endif /* ! __STDC__ */
 {
   KeyWidget key = 0;
   int mouse_p = 0;
@@ -145,12 +129,17 @@ parse_key_action_args (name, event, argv, argc, widget, mouse_p_ret)
 
 
 void
-highlight_key_action (widget, event, argv, argc)
-     KeyboardWidget widget;
+#ifdef __STDC__
+highlight_key_action (Widget ww, XEvent *event, String *argv, Cardinal *argc)
+#else /* ! __STDC__ */
+highlight_key_action (ww, event, argv, argc)
+     Widget ww;
      XEvent *event;
-     char *argv[];
-     int *argc;
+     String *argv;
+     Cardinal *argc;
+#endif /* ! __STDC__ */
 {
+  KeyboardWidget widget = (KeyboardWidget) ww;
   int mouse_p;
   KeyWidget key = parse_key_action_args ("HighlightKey", event,
 					 argv, *argc, widget, &mouse_p);
@@ -163,12 +152,17 @@ highlight_key_action (widget, event, argv, argc)
 
 
 void
-unhighlight_key_action (widget, event, argv, argc)
-     KeyboardWidget widget;
+#ifdef __STDC__
+unhighlight_key_action (Widget ww, XEvent *event, String *argv, Cardinal *argc)
+#else /* ! __STDC__ */
+unhighlight_key_action (ww, event, argv, argc)
+     Widget ww;
      XEvent *event;
-     char *argv[];
-     int *argc;
+     String *argv;
+     Cardinal *argc;
+#endif /* ! __STDC__ */
 {
+  KeyboardWidget widget = (KeyboardWidget) ww;
   int mouse_p;
   KeyWidget key = parse_key_action_args ("UnhighlightKey", event,
 					 argv, *argc, widget, &mouse_p);
@@ -181,12 +175,17 @@ unhighlight_key_action (widget, event, argv, argc)
 
 
 void
-toggle_key_action (widget, event, argv, argc)
-     KeyboardWidget widget;
+#ifdef __STDC__
+toggle_key_action (Widget ww, XEvent *event, String *argv, Cardinal *argc)
+#else /* ! __STDC__ */
+toggle_key_action (ww, event, argv, argc)
+     Widget ww;
      XEvent *event;
-     char *argv[];
-     int *argc;
+     String *argv;
+     Cardinal *argc;
+#endif /* ! __STDC__ */
 {
+  KeyboardWidget widget = (KeyboardWidget) ww;
   int mouse_p;
   KeyWidget key = parse_key_action_args ("ToggleKey", event, argv, *argc,
 					 widget, &mouse_p);
@@ -208,14 +207,19 @@ toggle_key_action (widget, event, argv, argc)
 }
 
 
-
 void
-simulate_KeyPress_action (widget, event, argv, argc)
-     KeyboardWidget widget;
+#ifdef __STDC__
+simulate_KeyPress_action (Widget ww, XEvent *event,
+			  String *argv, Cardinal *argc)
+#else /* ! __STDC__ */
+simulate_KeyPress_action (ww, event, argv, argc)
+     Widget ww;
      XEvent *event;
-     char *argv[];
-     int *argc;
+     String *argv;
+     Cardinal *argc;
+#endif /* ! __STDC__ */
 {
+  KeyboardWidget widget = (KeyboardWidget) ww;
   KeyWidget key = parse_key_action_args ("SimulateKeyPress", event, argv,
 					 *argc, widget, 0);
   if (key) simulate_key_event (key, 1);
@@ -223,12 +227,18 @@ simulate_KeyPress_action (widget, event, argv, argc)
 
 
 void
-simulate_KeyRelease_action (widget, event, argv, argc)
-     KeyboardWidget widget;
+#ifdef __STDC__
+simulate_KeyRelease_action (Widget ww, XEvent *event,
+			    String *argv, Cardinal *argc)
+#else /* ! __STDC__ */
+simulate_KeyRelease_action (ww, event, argv, argc)
+     Widget ww;
      XEvent *event;
-     char *argv[];
-     int *argc;
+     String *argv;
+     Cardinal *argc;
+#endif /* ! __STDC__ */
 {
+  KeyboardWidget widget = (KeyboardWidget) ww;
   KeyWidget key = parse_key_action_args ("SimulateKeyRelease", event,
 					 argv, *argc, widget, 0);
   if (key) simulate_key_event (key, 0);
@@ -236,12 +246,17 @@ simulate_KeyRelease_action (widget, event, argv, argc)
 
 
 void
-describe_key_action (widget, event, argv, argc)
-     KeyboardWidget widget;
+#ifdef __STDC__
+describe_key_action (Widget ww, XEvent *event, String *argv, Cardinal *argc)
+#else /* ! __STDC__ */
+describe_key_action (ww, event, argv, argc)
+     Widget ww;
      XEvent *event;
-     char *argv[];
-     int *argc;
+     String *argv;
+     Cardinal *argc;
+#endif /* ! __STDC__ */
 {
+  KeyboardWidget widget = (KeyboardWidget) ww;
   KeyWidget key = parse_key_action_args ("DescribeKey", event,
 					 argv, *argc, widget, 0);
   if (! key) return;
@@ -267,12 +282,17 @@ describe_key_action (widget, event, argv, argc)
 
 
 void
-track_key_action (widget, event, argv, argc)
-     KeyboardWidget widget;
+#ifdef __STDC__
+track_key_action (Widget ww, XEvent *event, String *argv, Cardinal *argc)
+#else /* ! __STDC__ */
+track_key_action (ww, event, argv, argc)
+     Widget ww;
      XEvent *event;
-     char *argv[];
-     int *argc;
+     String *argv;
+     Cardinal *argc;
+#endif /* ! __STDC__ */
 {
+  KeyboardWidget widget = (KeyboardWidget) ww;
   KeyWidget key = parse_key_action_args ("TrackKey", event,
 					 argv, *argc, widget, 0);
   if (!key) return;
@@ -286,12 +306,17 @@ track_key_action (widget, event, argv, argc)
 }
 
 void
-untrack_key_action (widget, event, argv, argc)
-     KeyboardWidget widget;
+#ifdef __STDC__
+untrack_key_action (Widget ww, XEvent *event, String *argv, Cardinal *argc)
+#else /* ! __STDC__ */
+untrack_key_action (ww, event, argv, argc)
+     Widget ww;
      XEvent *event;
-     char *argv[];
-     int *argc;
+     String *argv;
+     Cardinal *argc;
+#endif /* ! __STDC__ */
 {
+  KeyboardWidget widget = (KeyboardWidget) ww;
   parse_key_action_args ("UntrackKey", event, argv, *argc, widget, 0);
   if (event->xany.type != ButtonPress && event->xany.type != ButtonRelease)
     {
@@ -304,15 +329,16 @@ untrack_key_action (widget, event, argv, argc)
   widget->keyboard.tracking_key = 0;
 }
 
-#if __STDC__
-extern void sensitize_menu (KeyboardWidget, Widget, Bool);
-#endif
 
 void
+#ifdef __STDC__
+key_menu_pre_popup_hook (Widget menu, XtPointer client_data,
+			 XtPointer call_data)
+#else /* ! __STDC__ */
 key_menu_pre_popup_hook (menu, client_data, call_data)
      Widget menu;
      XtPointer client_data, call_data;
-
+#endif /* ! __STDC__ */
 {
   KeyboardWidget widget = (KeyboardWidget) client_data;
   KeyWidget key = widget->keyboard.key_under_mouse;
@@ -345,14 +371,20 @@ key_menu_pre_popup_hook (menu, client_data, call_data)
  */
 
 void
-keyboard_track_motion_hook (action_widget, client_data, action_name,
-			    event, argv, argc)
+#ifdef __STDC__
+keyboard_track_motion_hook (Widget action_widget, XtPointer client_data,
+			    String action_name, XEvent *event,
+			    String *ac, Cardinal *av)
+#else /* ! __STDC__ */
+keyboard_track_motion_hook (action_widget, client_data,
+			    action_name, event, ac, av)
      Widget action_widget;
      XtPointer client_data;
-     char *action_name;
+     String action_name;
      XEvent *event;
-     char **argv;
-     int *argc;
+     String *ac;
+     Cardinal *av;
+#endif /* ! __STDC__ */
 {
   if (action_widget != (Widget) client_data)	/* not the KeyboardWidget */
     return;
@@ -441,8 +473,12 @@ static unsigned long real_modifier_state = 0;
   (((KEY)->key.mouse_highlighted > 0) || ((KEY)->key.key_highlighted > 0))
 
 static void
+#ifdef __STDC__
+mouse_highlight_key (KeyWidget widget)
+#else /* ! __STDC__ */
 mouse_highlight_key (widget)
      KeyWidget widget;
+#endif /* ! __STDC__ */
 {
   KeyboardWidget keyboard = (KeyboardWidget) widget->core.parent;
   if (!key_highlighted_p (widget)) {
@@ -460,8 +496,12 @@ mouse_highlight_key (widget)
 
 
 static void
+#ifdef __STDC__
+mouse_dehighlight_key (KeyWidget widget)
+#else /* ! __STDC__ */
 mouse_dehighlight_key (widget)
      KeyWidget widget;
+#endif /* ! __STDC__ */
 {
   KeyboardWidget keyboard = (KeyboardWidget) widget->core.parent;
 
@@ -486,8 +526,12 @@ mouse_dehighlight_key (widget)
 
 
 static void
+#ifdef __STDC__
+highlight_key (KeyWidget widget)
+#else /* ! __STDC__ */
 highlight_key (widget)
      KeyWidget widget;
+#endif /* ! __STDC__ */
 {
   KeyboardWidget keyboard = (KeyboardWidget) widget->core.parent;
 
@@ -520,8 +564,12 @@ highlight_key (widget)
 }
 
 static void
+#ifdef __STDC__
+dehighlight_key (KeyWidget widget)
+#else /* ! __STDC__ */
 dehighlight_key (widget)
      KeyWidget widget;
+#endif /* ! __STDC__ */
 {
   KeyboardWidget keyboard = (KeyboardWidget) widget->core.parent;
   widget->key.key_highlighted--;
@@ -551,10 +599,14 @@ dehighlight_key (widget)
 
 
 void
+#ifdef __STDC__
+key_to_event (KeyWidget key, XEvent *event, int down_p)
+#else /* ! __STDC__ */
 key_to_event (key, event, down_p)
      KeyWidget key;
      XEvent *event;
      int down_p;
+#endif /* ! __STDC__ */
 {
   event->xkey.type = down_p ? KeyPress : KeyRelease;
   event->xkey.display = XtDisplay (key);
@@ -565,12 +617,15 @@ key_to_event (key, event, down_p)
   event->xkey.keycode = key->key.keycode;
 }
 
-extern Window XSendEvent_BadWindow;
 
 static void
+#ifdef __STDC__
+simulate_key_event (KeyWidget widget, int down_p)
+#else /* ! __STDC__ */
 simulate_key_event (widget, down_p)
      KeyWidget widget;
      int down_p;
+#endif /* ! __STDC__ */
 {
   KeyboardWidget keyboard = (KeyboardWidget) widget->core.parent;
   XEvent event;
@@ -630,25 +685,34 @@ simulate_key_event (widget, down_p)
 int mappingNotify_event_expected = 0;
 
 static Bool
+#ifdef __STDC__
+mapping_event_p (Display *dpy, XEvent *event, char *closure)
+#else /* ! __STDC__ */
 mapping_event_p (dpy, event, closure)
      Display *dpy;
      XEvent *event;
      char *closure;
+#endif /* ! __STDC__ */
 {
   if (event->xany.type == MappingNotify) *closure = 1;
   return False;
 }
 
 void
+#ifdef __STDC__
+keyboard_handle_mapping_notify (Widget widget, XtPointer client_data,
+				XEvent *event, Boolean *cont)
+#else /* ! __STDC__ */
 keyboard_handle_mapping_notify (widget, client_data, event, cont)
      Widget widget;
      XtPointer client_data;
      XEvent *event;
      Boolean *cont;
+#endif /* ! __STDC__ */
 {
   char events_queued_p = 0;
   XRefreshKeyboardMapping (&event->xmapping);
-  init_modifier_mapping (widget);
+  init_modifier_mapping ((KeyboardWidget) widget);
   XSync (XtDisplay (widget), 0);
   if (XCheckIfEvent (XtDisplay (widget), event,
 		     mapping_event_p, &events_queued_p))
@@ -668,11 +732,16 @@ keyboard_handle_mapping_notify (widget, client_data, event, cont)
 }
 
 void
+#ifdef __STDC__
+keyboard_handle_keymap_notify (Widget w, XtPointer client_data, XEvent *event,
+			       Boolean *cont)
+#else /* ! __STDC__ */
 keyboard_handle_keymap_notify (w, client_data, event, cont)
      Widget w;
      XtPointer client_data;
      XEvent *event;
      Boolean *cont;
+#endif /* ! __STDC__ */
 {
   /* To prevent getting out of sync with the real state of the
      keyboard during those unfortunate moments when we don't have
@@ -731,9 +800,13 @@ keyboard_handle_keymap_notify (w, client_data, event, cont)
 
 
 KeyWidget
+#ifdef __STDC__
+window_to_key (Display *dpy, Window window)
+#else /* ! __STDC__ */
 window_to_key (dpy, window)
      Display *dpy;
      Window window;
+#endif /* ! __STDC__ */
 {
   KeyWidget key = (KeyWidget) XtWindowToWidget (dpy, window);
   if (! key) return 0;
@@ -743,9 +816,13 @@ window_to_key (dpy, window)
 
 
 KeyWidget
+#ifdef __STDC__
+keycode_to_key (KeyboardWidget keyboard, KeyCode code)
+#else /* ! __STDC__ */
 keycode_to_key (keyboard, code)
      KeyboardWidget keyboard;
      KeyCode code;
+#endif /* ! __STDC__ */
 {
   int i, j;
   if (! code) return 0;
@@ -758,8 +835,12 @@ keycode_to_key (keyboard, code)
 
 
 static void
+#ifdef __STDC__
+clear_modifier_flags (KeyboardWidget widget)
+#else /* ! __STDC__ */
 clear_modifier_flags (widget)
      KeyboardWidget widget;
+#endif /* ! __STDC__ */
 {
   int i, j;
   memset (widget->keyboard.modifier_vector, 0, 32);
@@ -771,8 +852,12 @@ clear_modifier_flags (widget)
 
 
 void
+#ifdef __STDC__
+init_modifier_mapping (KeyboardWidget widget)
+#else /* ! __STDC__ */
 init_modifier_mapping (widget)
      KeyboardWidget widget;
+#endif /* ! __STDC__ */
 {
   Display *dpy = XtDisplay (widget);
   XModifierKeymap *modifier_map;
