@@ -1,6 +1,7 @@
 /* Resource and command-line junk
  *
- * xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
+ * xkeycaps, Copyright (c) 1991, 1992, 1993, 1996, 1997
+ *  Jamie Zawinski <jwz@netscape.com>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -102,17 +103,18 @@ static char *xkeycapsDefaults[] = {
   "*selectKbd*List.forceColumns:	true",
   "*selectKbd*label.internalHeight:	5",
 
-  "*selectKbd*List.internalWidth:	 5",
-  "*selectKbd*List.columnSpacing:	 10",
+  "*selectKbd*List.internalWidth:	 2",
+  "*selectKbd*List.columnSpacing:	 5",
   "*selectKbd*List.rowSpacing:		 0",
 
+  "*selectKbd*vendorBox*Label.internalWidth:       20",
+  "*selectKbd*vendorBox*Label.internalHeight:      3",
+
   "*selectKbd*keyboardBox*Label.internalWidth:     20",
   "*selectKbd*keyboardBox*Label.internalHeight:    3",
-  "*selectKbd*keyboardBox*keyboardsList.internalWidth: 10",
 
   "*selectKbd*keymapBox*Label.internalWidth:       20",
   "*selectKbd*keymapBox*Label.internalHeight:      3",
-  "*selectKbd*keymapBox*keymapsList.internalWidth: 10",
 
   "*selectKbd*label2.allowResize:		  true",
   "*selectKbd*label2.internalWidth:           	    30",
@@ -169,6 +171,8 @@ static char *xkeycapsDefaults[] = {
   "*selectKbd.title:			Select Keyboard",
   "*writeQuery.title:			Question",
   "*restoreQuery.title:			Question",
+  "*overwriteQuery.title:		Question",
+  "*wroteFileMessage.title:		Message",
 
   "*buttons.quit.label:			Quit",
   "*buttons.focus.label:		Type At Window",
@@ -199,6 +203,7 @@ static char *xkeycapsDefaults[] = {
   "*editKey*modifierBox.modControl.label:Control",
   "*editKey*modifierBox.modLock.label:	Lock",
 
+  "*selectKbd*vendors.label:		Vendors:",
   "*selectKbd*keyboards.label:		Keyboards:",
   "*selectKbd*keymaps.label:		Layouts:",
   "*selectKbd*label.label:		Select a Keyboard and Layout:",
@@ -208,6 +213,8 @@ static char *xkeycapsDefaults[] = {
 
   "*writeQuery*label.font:	*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
   "*restoreQuery*label.font:	*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
+  "*overwriteQuery*label.font:	*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
+  "*wroteFileMessage*label.font:*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
   "*noKeysymDBError*label.font:	*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
   "*unknownKeysymDBError*label.font: *-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
   "*magicKeyError*label.font:	     *-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
@@ -221,6 +228,8 @@ static char *xkeycapsDefaults[] = {
 
   "*writeQuery*Command.font:	*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
   "*restoreQuery*Command.font:	*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
+  "*overwriteQuery*Command.font:*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
+  "*wroteFileMessage*Command.font:*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
   "*noKeysymDBError*Command.font:*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
   "*unknownKeysymDBError*Command.font:*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
   "*magicKeyError*Command.font:	*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*",
@@ -248,6 +257,16 @@ that is displayed, you will lose big.",
   "*restoreQuery*yes.label:		Restore",
   "*restoreQuery*no.label:		Cancel",
 
+  "*overwriteQuery*label.label:		\\nOverwrite file %s?",
+  "*wroteFileMessage*label.label:	\\nWrote output to the file\\n\
+         %s\\n\
+\\n\
+You should modify your login script to contain a line like\\n\
+\\n\
+         xmodmap ~/.xmodmap-`uname -n`\\n\
+\\n(\
+those are backquotes.)\\n",
+
   "*noKeysymDBError.title:		Error",
   "*unknownKeysymDBError.title:		Error",
   "*noKeysymDBError*label.label:	\\n\
@@ -365,6 +384,16 @@ different modifier bit.",
   "*restoreQuery*buttons.hSpace:			20",
   "*restoreQuery*buttons.vSpace:			20",
 
+  "*overwriteQuery*label.internalWidth:			20",
+  "*overwriteQuery*label.internalHeight:		0",
+  "*overwriteQuery*buttons.hSpace:			20",
+  "*overwriteQuery*buttons.vSpace:			20",
+
+  "*wroteFileMessage*label.internalWidth:		20",
+  "*wroteFileMessage*label.internalHeight:		0",
+  "*wroteFileMessage*buttons.hSpace:			20",
+  "*wroteFileMessage*buttons.vSpace:			20",
+
   "*writeQuery*label.internalWidth:			20",
   "*writeQuery*label.internalHeight:			0",
   "*writeQuery*buttons.hSpace:				20",
@@ -427,6 +456,5 @@ static XrmOptionDescRec options [] = {
   { "-no_xtrap",	"*useXTrap",			XrmoptionNoArg,"off" },
 #endif
   { "-keyboard",	"*Keyboard.keyboard",		XrmoptionSepArg, 0 },
-  { "-kbd",		"*Keyboard.keyboard",		XrmoptionSepArg, 0 },
-  { "-help",		"*Keyboard.keyboard",		XrmoptionNoArg, "help"}
+  { "-kbd",		"*Keyboard.keyboard",		XrmoptionSepArg, 0 }
 };
