@@ -4,7 +4,7 @@
  * for the co-Xist 3.0 X server.  By Eric Benson <eb@NeXT.com>.
  */
 
-static KeyCode NeXT_codes [] = {
+static const KeyCode NeXT_codes [] = {
   /* Row 0 */
   81, 82, 83, 84, 85, 88, 87, 86, 38, 39, 40, 37, 36, 35,
   46, 47, 48, 45,
