@@ -5,7 +5,7 @@
  * Tested on a AViiON 300 running dgux 5.4 generic 
  */
 
-static KeyCode aviion300_codes [] = {
+static const KeyCode aviion300_codes [] = {
   /* Row 0 */
   9,
   8, 16, 24, 32,
