@@ -3,7 +3,7 @@
  * This file describes the keycodes of the DELL PC keyboard.
  */
 
-static KeyCode dell_codes [] = {
+static const KeyCode dell_codes [] = {
   /* Row 0 */
   9,
   67, 68, 69, 70,
