@@ -4,7 +4,7 @@
  * keyboard.
  */
 
-static KeyCode explorer_codes [] = {
+static const KeyCode explorer_codes [] = {
   /* Row 0 */
   8,
   15, 16, 17, 18,
