@@ -4,7 +4,7 @@
  * By black@westford.ccur.com.
  */
 
-static KeyCode ga5k_codes [] = {
+static const KeyCode ga5k_codes [] = {
 
   /* Row 0 */
   145,
