@@ -8,7 +8,7 @@
  * does not deal with that.
  */
 
-static KeyCode hclpc_codes [] = {
+static const KeyCode hclpc_codes [] = {
 
   /* Row 0 */
   8,
