@@ -5,7 +5,7 @@
  * By Mark Borges <mdb@cdc.noaa.gov>
  */
 
-static KeyCode hp4032x_codes [] = {
+static const KeyCode hp4032x_codes [] = {
 
   /* Row 0 */
   18, 17,
