@@ -4,7 +4,7 @@
  * By Hide Horiuchi <hide@sierra.com>.
  */
 
-static KeyCode hp700rx_codes [] = {
+static const KeyCode hp700rx_codes [] = {
 
   /* Row 0 */
   17,
@@ -16,7 +16,10 @@ static KeyCode hp700rx_codes [] = {
   /* Row 2 */
   23, 31, 39, 47, 46, 55, 63, 70, 71, 79, 78, 87, 94, 111,
   112, 119, 120,
-  127, 128, 135, 129,
+  127, 128, 135, 141,
+	/* Note: the last keycode on the preceeding line (keypad-minus)
+	   used to be 129, but Corne Beerse <beerse@ats.nld.alcatel.nl>
+	   says that 141 is correct, with HPUX 9.05. */
 
   /* Row 3 */
   22, 30, 38, 45, 54, 53, 62, 69, 76, 77, 86, 93, 100, 101,
