@@ -4,7 +4,7 @@
  * keyboards.  By Dave Brooks <dbrooks@inel.gov>
  */
 
-static KeyCode hpitf_codes [] = {
+static const KeyCode hpitf_codes [] = {
 
   /* Row 0 */
   15, 86,
@@ -16,22 +16,22 @@ static KeyCode hpitf_codes [] = {
   71, 70, 69, 68, 67, 66, 65, 64, 96, 97, 98, 99, 100, 101,
   102, 103,
   29, 25, 27, 31,
-  
+
   /* Row 3 */
   63, 62, 61, 60, 59, 58, 57, 56, 104, 105, 106, 107, 108, 109,
   110, 111,
   21, 17, 19, 23,
-  
+
   /* Row 4 */
   55, 14, 53, 52, 51, 50, 49, 48, 112, 113, 114, 115, 116, 117,
   118, 119,
   16, 18, 20, 22,
-  
+
   /* Row 5 */
   39, 13, 36, 35, 34, 33, 32, 128, 120, 121, 122, 123, 12,
   125, 134, 127,
   24, 26, 28, 46,
-  
+
   /* Row 6 */
   87,
   11, 129, 10,
