@@ -4,7 +4,7 @@
  * By Markus Stumpf <stumpf@informatik.tu-muenchen.de>
  */
 
-static KeyCode hppc_codes [] = {
+static const KeyCode hppc_codes [] = {
 
   /* Row 0 */
   39,
