@@ -4,7 +4,7 @@
  * By Todd Richmond <todd@sdt.com>
  */
 
-static KeyCode hppc_de_codes [] = {
+static const KeyCode hppcde_codes [] = {
 
   /* Row 0 */
   39,
