@@ -6,7 +6,7 @@
  * By Chris Paulson-Ellis <cpaulson-ellis@email.meto.govt.uk>
  */
 
-static KeyCode hppcuk700rx_codes [] = {
+static const KeyCode hppcuk700rx_codes [] = {
 
   /* Row 0 */
   17,
