@@ -5,7 +5,7 @@
  * also used with some IBM PCs.  By Anthony Thyssen <anthony@cit.gu.edu.au>.
  */
 
-static KeyCode labtam_codes [] = {
+static const KeyCode labtam_codes [] = {
 
   /* Row 0 */
   118, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 0, 134,
