@@ -11,7 +11,7 @@
  * By Jamie Zawinski <jwz@netscape.com>
  */
 
-static KeyCode linux101_3_codes [] = {
+static const KeyCode linux101_3_codes [] = {
 
   /* Row 0 */
   9, 
