@@ -4,7 +4,7 @@
  * on Linux with Xfree86 2.0.  By Jan Wedekind <jan@todonix.ruhr.de>
  */
 
-static KeyCode linux102_codes [] = {
+static const KeyCode linux102_codes [] = {
   /* Row 0 */
   9,
   67, 68, 69, 70,
