@@ -8,7 +8,7 @@
 # define lk201_codes lk401_codes
 #endif
 
-static KeyCode lk201_codes [] = {
+static const KeyCode lk201_codes [] = {
 
   /* Row 0 */
   86, 87, 88, 89, 90,
