@@ -12,7 +12,7 @@
  * necessary because each key has two keycodes...
  */
 
-static KeyCode lk421_codes [] = {
+static const KeyCode lk421_codes [] = {
 
   /* Row 0 */
   86, 87, 88, 89, 90,
