@@ -5,7 +5,7 @@
  * Inteq DEAP Support, Aberdeen.
  */
 
-static KeyCode mac_codes [] = {
+static const KeyCode mac_codes [] = {
 
   /* Row 0 */
   61,
