@@ -4,7 +4,7 @@
  * By Cliff Marcellus <cliff@phys.ucalgary.ca>.
  */
 
-static KeyCode mag3k_codes [] = {
+static const KeyCode mag3k_codes [] = {
 
   /* Row 0 */
   9, 17, 25, 33,
