@@ -4,7 +4,7 @@
  * By Michael Elbel <me@pcs.com>
  */
 
-static KeyCode magat_codes [] = {
+static const KeyCode magat_codes [] = {
 
   /* Row 0 */
   126,
