@@ -3,7 +3,7 @@
  * This file describes the keycodes of the NCD X terminal N101 keyboard.
  */
 
-static KeyCode ncd101_codes [] = {
+static const KeyCode ncd101_codes [] = {
 
   /* Row 0 */
   8,
