@@ -3,7 +3,7 @@
  * This file describes the keycodes of the NCD X terminal N102 keyboard.
  */
 
-static KeyCode ncd102_codes [] = {
+static const KeyCode ncd102_codes [] = {
 
   /* Row 0 */
   8,
