@@ -4,7 +4,7 @@
  * By Francois Regis Colin <fcolin@cenatls.cena.dgac.fr>
  */
 
-static KeyCode ncd102f_codes [] = {
+static const KeyCode ncd102f_codes [] = {
 
   /* Row 0 */
   8,
