@@ -4,7 +4,7 @@
  * By Bj|rn Wennberg <bjornw@edb.tih.no>
  */
 
-static KeyCode ncd102n_codes [] = {
+static const KeyCode ncd102n_codes [] = {
 
   /* Row 0 */
   8,
