@@ -4,7 +4,7 @@
  * keyboard.  By Pekka Nikander <pnr@innopoli.ajk.tele.fi>
  */
 
-static KeyCode ncd102sf_codes [] = {
+static const KeyCode ncd102sf_codes [] = {
 
   /* Row 0 */
   8,
