@@ -3,7 +3,7 @@
  * This file describes the keycodes of the NCD X terminal N97 keyboard.
  */
 
-static KeyCode ncd97_codes [] = {
+static const KeyCode ncd97_codes [] = {
 
   /* Row 0 */
   16, 15, 23, 31,
