@@ -4,7 +4,7 @@
  * By Jason Merrill <jason@jarthur.claremont.edu>
  */
 
-static KeyCode ncdpc_codes [] = {
+static const KeyCode ncdpc_codes [] = {
 
   /* Row 0 */
   59,
