@@ -14,7 +14,7 @@
  * if pressed and released twice.
  */
 
-static KeyCode nws1250_codes [] = {
+static const KeyCode nws1250_codes [] = {
 
   /* Row 0 */
   0,
