@@ -15,7 +15,7 @@
  * 80 KeyPress, 80 KeyRelease if pressed and released twice.
  */
 
-static KeyCode nws3410_codes [] = {
+static const KeyCode nws3410_codes [] = {
 
   /* Row 0 */
   8, 9, 10, 11, 12,
