@@ -6,7 +6,7 @@
  * SCO ODT 110 keycodes def by Steven W. Orr <steveo@world.std.com>.
  */
 
-static KeyCode phasex110_codes [] = {
+static const KeyCode phasex110_codes [] = {
 
   /* Row 0 */
   8,
