@@ -8,7 +8,7 @@
  *
  */
 
-static KeyCode phasex110b_codes [] = {
+static const KeyCode phasex110b_codes [] = {
 
   /* Row 0 */
   8,
