@@ -4,7 +4,7 @@
  * By Cliff Marcellus (cliff@phys.ucalgary.ca)
  */
 
-static KeyCode rs2030_codes [] = {
+static const KeyCode rs2030_codes [] = {
 
   /* Row 0 */
   9,
