@@ -4,7 +4,7 @@
  * By Tom McConnell <tmcconne@sedona.intel.com>
  */
 
-static KeyCode rs6k_codes [] = {
+static const KeyCode rs6k_codes [] = {
 
   /* Row 0 */
   118,
