@@ -4,7 +4,7 @@
  * By Joerg Stippa <stippa@isa.de>
  */
 
-static KeyCode rs6kde_codes [] = {
+static const KeyCode rs6kde_codes [] = {
 
   /* Row 0 */
   118,
