@@ -4,7 +4,7 @@
  * By Torbj|rn Lindgren <tl@cd.chalmers.se>.
  */
 
-static KeyCode rt_codes [] = {
+static const KeyCode rt_codes [] = {
 
   /* Row 0 */
   8,
