@@ -4,7 +4,7 @@
  * By Torbj|rn Lindgren <tl@cd.chalmers.se>
  */
 
-static KeyCode rtsw_codes [] = {
+static const KeyCode rtsw_codes [] = {
 
   /* Row 0 */
   8,
