@@ -4,7 +4,7 @@
  * By Steven W. Orr <steveo@world.std.com>.
  */
 
-static KeyCode sco110_codes [] = {
+static const KeyCode sco110_codes [] = {
 
   /* Row 0 */
   8,
