@@ -4,7 +4,7 @@
  * with IRIX 4.* or older.  By Simon Leinen <simon@lia.di.epfl.ch>
  */
 
-static KeyCode sgi4_codes [] = {
+static const KeyCode sgi4_codes [] = {
 
   /* Row 0 */
   14,
