@@ -5,7 +5,7 @@
  * By Benedikt Kessler <bjk@munich.sgi.com> for Irix 5.2.
  */
 
-static KeyCode sgi5de_codes [] = {
+static const KeyCode sgi5de_codes [] = {
 
   /* Row 0 */
   16,
