@@ -4,7 +4,7 @@
  * By Christopher Davis <ckd@kei.com>
  */
 
-static KeyCode sun101a_codes [] = {
+static const KeyCode sun101a_codes [] = {
 
   /* Row 0 */
   36,
