@@ -3,7 +3,7 @@
  * This file describes the keycodes of the Sun type 2 keyboard.
  */
 
-static KeyCode sun2_codes [] = {
+static const KeyCode sun2_codes [] = {
 
   /* Row 0 */
   8, 10,
