@@ -3,7 +3,7 @@
  * This file describes the keycodes of the Sun type 3 keyboard.
  */
 
-static KeyCode sun3_codes [] = {
+static const KeyCode sun3_codes [] = {
 
   /* Row 0 */
   8, 10,
