@@ -6,7 +6,7 @@
  * Note that the X Consortium R6 keycodes are totally different.
  */
 
-static KeyCode sun4_codes [] = {
+static const KeyCode sun4_codes [] = {
 
   /* Row 0 */
   8, 10,
