@@ -4,7 +4,7 @@
  * By Torbj|rn Lindgren <tl@cd.chalmers.se>.
  */
 
-static KeyCode sun4sw_codes [] = {
+static const KeyCode sun4sw_codes [] = {
 
   /* Row 0 */
   8, 10,
