@@ -10,7 +10,7 @@
  * similar, their keycodes differ more.
  */
 
-static KeyCode sun5_codes [] = {
+static const KeyCode sun5_codes [] = {
 
   /* Row 0 */
   125, 22,
