@@ -7,7 +7,7 @@
  * and Andreas Schuch <schuch@physik.uni-kl.de>.
  */
 
-static KeyCode sun5de_codes [] = {
+static const KeyCode sun5de_codes [] = {
 
   /* Row 0 */
   125, 36,
