@@ -4,7 +4,7 @@
  * By Kazutaka Yokota (yokota@zodiac.mech.utsunomiya-u.ac.jp).
  */
 
-static KeyCode sun5jp_codes [] = {
+static const KeyCode sun5jp_codes [] = {
 
   /* Row 0 */
   125, 36,
