@@ -6,7 +6,7 @@
  * By Carl Witty <cwitty@ai.mit.edu> and Sylvain Meunier <meunier@inf.enst.fr>.
  */
 
-static KeyCode sun5pc_codes [] = {
+static const KeyCode sun5pc_codes [] = {
 
   /* Row 0 */
   125, 36,
