@@ -5,7 +5,7 @@
  *
  */
 
-static KeyCode sun5sw_codes [] = {
+static const KeyCode sun5sw_codes [] = {
 
   /* Row 0 */
   125, 36,
