@@ -8,7 +8,7 @@
  *
  */
 
-static KeyCode sun5swfr_codes [] = {
+static const KeyCode sun5swfr_codes [] = {
 
   /* Row 0 */
   125, 36,
