@@ -5,7 +5,7 @@
  * By Joe English <joe@trystero.art.com>.
  */
 
-static KeyCode tek101_codes [] = {
+static const KeyCode tek101_codes [] = {
 
   /* Row 0 */
   16,
