@@ -6,7 +6,7 @@
  * By Christoph Tietz <tietz@gmd.de>.
  */
 
-static KeyCode tek102_codes [] = {
+static const KeyCode tek102_codes [] = {
 
   /* Row 0 */
   16,
