@@ -6,7 +6,7 @@
  * By Michael Lemke <michael@io.as.utexas.edu>.
  */
 
-static KeyCode tek119_codes [] = {
+static const KeyCode tek119_codes [] = {
 
   /* Row 0 */
   17, 16,
