@@ -5,7 +5,7 @@
  * By Juergen Stuber <juergen.stuber@mpi-sb.mpg.de>.
  */
 
-static KeyCode tek200_codes [] = {
+static const KeyCode tek200_codes [] = {
 
   /* Row 0 */
   15, 23, 106, 39, 47,
