@@ -5,7 +5,7 @@
  * By Torbj|rn Lindgren <tl@ae.chalmers.se>
  */
 
-static KeyCode tek401_codes [] = {
+static const KeyCode tek401_codes [] = {
 
   /* Row 0 */
   15, 23, 106, 39, 47,
