@@ -6,7 +6,7 @@
  * By Robert Zwickenpflug <zpg@mmk.e-technik.tu-muenchen.de>
  */
 
-static KeyCode teksun4_codes [] = {
+static const KeyCode teksun4_codes [] = {
 
   /* Row 0 */
   10, 16,
