@@ -4,7 +4,7 @@
  * By Mats Wichmann <mats@alruna.com>
  */
 
-static KeyCode tt_codes [] = {
+static const KeyCode tt_codes [] = {
 
   /* Row 0 */
   67, 68, 69, 70, 71, 72, 73, 74, 75, 76,
