@@ -4,7 +4,7 @@
  * By Christian Goetze <c-goetze@u-aizu.ac.jp>
  */
 
-static struct key_strings xmint_caps [] = {
+static const struct key_strings xmint_caps [] = {
 
  /* Row 0 */
 
