@@ -16,7 +16,7 @@
  * By Dan R. Greening <greening@sti.com>.
  */
 
-static KeyCode xoft2_codes [] = {
+static const KeyCode xoft2_codes [] = {
 
   /* Row 0 */
   35,
